==> ?f=jw_disqus-v3.5_j1.5-3.x.zip: README.md <==
Disqus Comments (for Joomla!)
==========================

"Disqus Comments (for Joomla!)" integrates the Disqus comments system & service into any Joomla! based website. Disqus (pronounced 'discuss') is a service and tool for web comments and discussions - currently the most popular comments-as-a-service provider worldwide. It makes commenting easier and more interactive, while connecting websites and commenters across a thriving discussion community.

In short, the most important features of the service are realtime comments, inline media embedding, mobile commenting, social integration with Twitter, Facebook & other services and great moderation & anti-spam tools.

You can learn more about all Disqus features at: http://disqus.com/features

Signup for a free account at: http://disqus.com


## WHY CHOOSE DISQUS? HIGHLIGHTS OF THE DISQUS COMMENT SYSTEM
Web comments can be difficult for both websites and their readers. We think Disqus is the solution. Disqus makes it easier for people to comment and track their contributions on a single profile which they can display as a comment blog. After all, there is no difference between a great comment and a great published article.

Disqus makes managing discussions on one or multiple websites painless. With a powerful and intuitive admin interface, Disqus allows website owners to spend time elsewhere while Disqus takes care of the comments.

Key benefits for Websites, Publishers, Bloggers
* Threaded comments and comment ratings
* Powerful moderation and admin tools
* Filter out spam, trolls, and unwanted commenters
* Enable your visitors to become a real community
* Moderation by email or mobile
* More comments and increased engagement
* Connected with a large discussion community
* Increased exposure and readership

Key benefits for Commenters, Readers
* Track and manage comments and replies
* Verified commenter reputations across sites
* More control over your own comments on websites
* Never lose your comments, even if the website goes away
* Build a global profile, or comment blog, to collect and show off what you're saying
* Easier to comment on websites using Disqus
* Reply to comments through email or mobile
* Edit and republish comments with one click


## EXTENSION FEATURES
- Options for comments counter/anchor link for listing and article pages
- Choose to integrate Disqus comments in specific categories and/or menu items
- Neutral design for easy integration on any template design. Use CSS for total design control: http://bit.ly/disqusStyling
- Fully MVC skinnable. Just copy the /plugins/content/jw_disqus/tmpl folder (in Joomla! 1.5) or /plugins/content/jw_disqus/jw_disqus/tmpl (in Joomla! 2.5+) inside your Joomla! template's /html folder, rename to /html/jw_disqus and start tweaking the HTML and CSS!
- Option for testing Disqus comments plugin locally before going live.


## LEARN MORE
Visit the Disqus Comments (for Joomla!) product page at: http://www.joomlaworks.net/extensions/free-premium/disqus-comments-for-joomla-package

==> ?f=jw_disqus-v3.6.0_j1.5-3.x.zip: README.md <==
Disqus Comments (for Joomla)
==========================

"Disqus Comments (for Joomla)" integrates the Disqus comments system & service into any Joomla based website. Disqus (pronounced 'discuss') is a service and tool for web comments and discussions - currently the most popular comments-as-a-service provider worldwide. It makes commenting easier and more interactive, while connecting websites and commenters across a thriving discussion community.

In short, the most important features of the service are realtime comments, inline media embedding, mobile commenting, social integration with Twitter, Facebook & other services and great moderation & anti-spam tools.

You can learn more about all Disqus features at: http://disqus.com/features

Signup for a free account at: http://disqus.com


## WHY CHOOSE DISQUS? HIGHLIGHTS OF THE DISQUS COMMENT SYSTEM
Web comments can be difficult for both websites and their readers. We think Disqus is the solution. Disqus makes it easier for people to comment and track their contributions on a single profile which they can display as a comment blog. After all, there is no difference between a great comment and a great published article.

Disqus makes managing discussions on one or multiple websites painless. With a powerful and intuitive admin interface, Disqus allows website owners to spend time elsewhere while Disqus takes care of the comments.

Key benefits for Websites, Publishers, Bloggers
* Threaded comments and comment ratings
* Powerful moderation and admin tools
* Filter out spam, trolls, and unwanted commenters
* Enable your visitors to become a real community
* Moderation by email or mobile
* More comments and increased engagement
* Connected with a large discussion community
* Increased exposure and readership

Key benefits for Commenters, Readers
* Track and manage comments and replies
* Verified commenter reputations across sites
* More control over your own comments on websites
* Never lose your comments, even if the website goes away
* Build a global profile, or comment blog, to collect and show off what you're saying
* Easier to comment on websites using Disqus
* Reply to comments through email or mobile
* Edit and republish comments with one click


## EXTENSION FEATURES
- Options for comments counter/anchor link for listing and article pages
- Choose to integrate Disqus comments in specific categories and/or menu items
- Neutral design for easy integration on any template design. Use CSS for total design control: http://bit.ly/disqusStyling
- Fully MVC skinnable. Just copy the /plugins/content/jw_disqus/tmpl folder (in Joomla 1.5) or /plugins/content/jw_disqus/jw_disqus/tmpl (in Joomla 2.5+) inside your Joomla template's /html folder, rename to /html/jw_disqus and start tweaking the HTML and CSS!
- Option for testing Disqus comments plugin locally before going live.


## LEARN MORE
Visit the Disqus Comments (for Joomla) product page at: http://www.joomlaworks.net/extensions/free/disqus-comments-for-joomla
